IntHint class final

A whole number, moving by step between min and max where either is given. LoopCut.cuts is one of these.

Inheritance

Constructors

IntHint({int? min, int? max, int step = 1})
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
max → int?
final
min → int?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
step → int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited