RigNode class final

One node of a rig as retargeting reads it.

Constructors

RigNode({required int id, required String name, required Matrix4 restLocal, int? parent})
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
id → int
What RigTrack.nodeId and RigNode.parent name it by.
final
name → String
What a BoneMap matches it by.
final
parent → int?
final
restLocal → Matrix4
The rest pose, relative to parent.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited